==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/botservice/kotlin/inputs/DirectLineChannelPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.botservice.kotlin.inputs

import com.pulumi.azurenative.botservice.inputs.DirectLineChannelPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The parameters to provide for the Direct Line channel.
 * @property directLineEmbedCode Direct Line embed code of the resource
 * @property extensionKey1 The extensionKey1
 * @property extensionKey2 The extensionKey2
 * @property sites The list of Direct Line sites
 */
public data class DirectLineChannelPropertiesArgs(
    public val directLineEmbedCode: Output<String>? = null,
    public val extensionKey1: Output<String>? = null,
    public val extensionKey2: Output<String>? = null,
    public val sites: Output<List<DirectLineSiteArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.botservice.inputs.DirectLineChannelPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.botservice.inputs.DirectLineChannelPropertiesArgs =
        com.pulumi.azurenative.botservice.inputs.DirectLineChannelPropertiesArgs.builder()
            .directLineEmbedCode(directLineEmbedCode?.applyValue({ args0 -> args0 }))
            .extensionKey1(extensionKey1?.applyValue({ args0 -> args0 }))
            .extensionKey2(extensionKey2?.applyValue({ args0 -> args0 }))
            .sites(
                sites?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [DirectLineChannelPropertiesArgs].
 */
@PulumiTagMarker
public class DirectLineChannelPropertiesArgsBuilder internal constructor() {
    private var directLineEmbedCode: Output<String>? = null

    private var extensionKey1: Output<String>? = null

    private var extensionKey2: Output<String>? = null

    private var sites: Output<List<DirectLineSiteArgs>>? = null

    /**
     * @param value Direct Line embed code of the resource
     */
    @JvmName("mhsiqabjjtujfrws")
    public suspend fun directLineEmbedCode(`value`: Output<String>) {
        this.directLineEmbedCode = value
    }

    /**
     * @param value The extensionKey1
     */
    @JvmName("erdnlqeyjuibngwl")
    public suspend fun extensionKey1(`value`: Output<String>) {
        this.extensionKey1 = value
    }

    /**
     * @param value The extensionKey2
     */
    @JvmName("ksiflxyuatjwfqhy")
    public suspend fun extensionKey2(`value`: Output<String>) {
        this.extensionKey2 = value
    }

    /**
     * @param value The list of Direct Line sites
     */
    @JvmName("xnwphytwspxlptwh")
    public suspend fun sites(`value`: Output<List<DirectLineSiteArgs>>) {
        this.sites = value
    }

    @JvmName("affbhdlrsvwokthw")
    public suspend fun sites(vararg values: Output<DirectLineSiteArgs>) {
        this.sites = Output.all(values.asList())
    }

    /**
     * @param values The list of Direct Line sites
     */
    @JvmName("itjcvxfeuxwecdjk")
    public suspend fun sites(values: List<Output<DirectLineSiteArgs>>) {
        this.sites = Output.all(values)
    }

    /**
     * @param value Direct Line embed code of the resource
     */
    @JvmName("cswycqmigmslexfj")
    public suspend fun directLineEmbedCode(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.directLineEmbedCode = mapped
    }

    /**
     * @param value The extensionKey1
     */
    @JvmName("cjcufbetdquclrmb")
    public suspend fun extensionKey1(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.extensionKey1 = mapped
    }

    /**
     * @param value The extensionKey2
     */
    @JvmName("phktksukwgecowum")
    public suspend fun extensionKey2(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.extensionKey2 = mapped
    }

    /**
     * @param value The list of Direct Line sites
     */
    @JvmName("nndjsyrpanpnrhcc")
    public suspend fun sites(`value`: List<DirectLineSiteArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sites = mapped
    }

    /**
     * @param argument The list of Direct Line sites
     */
    @JvmName("limsjjhcmfngflli")
    public suspend fun sites(argument: List<suspend DirectLineSiteArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            DirectLineSiteArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.sites = mapped
    }

    /**
     * @param argument The list of Direct Line sites
     */
    @JvmName("vdmknyrbkotoqyfa")
    public suspend fun sites(vararg argument: suspend DirectLineSiteArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            DirectLineSiteArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.sites = mapped
    }

    /**
     * @param argument The list of Direct Line sites
     */
    @JvmName("wipwtjdtltasqfkv")
    public suspend fun sites(argument: suspend DirectLineSiteArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(DirectLineSiteArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.sites = mapped
    }

    /**
     * @param values The list of Direct Line sites
     */
    @JvmName("xjlwknuolkmwmxpl")
    public suspend fun sites(vararg values: DirectLineSiteArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sites = mapped
    }

    internal fun build(): DirectLineChannelPropertiesArgs = DirectLineChannelPropertiesArgs(
        directLineEmbedCode = directLineEmbedCode,
        extensionKey1 = extensionKey1,
        extensionKey2 = extensionKey2,
        sites = sites,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/botservice/kotlin/inputs/DirectLineChannelPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.botservice.kotlin.inputs

import com.pulumi.azurenative.botservice.inputs.DirectLineChannelPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The parameters to provide for the Direct Line channel.
 * @property directLineEmbedCode Direct Line embed code of the resource
 * @property extensionKey1 The extensionKey1
 * @property extensionKey2 The extensionKey2
 * @property sites The list of Direct Line sites
 */
public data class DirectLineChannelPropertiesArgs(
    public val directLineEmbedCode: Output<String>? = null,
    public val extensionKey1: Output<String>? = null,
    public val extensionKey2: Output<String>? = null,
    public val sites: Output<List<DirectLineSiteArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.botservice.inputs.DirectLineChannelPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.botservice.inputs.DirectLineChannelPropertiesArgs =
        com.pulumi.azurenative.botservice.inputs.DirectLineChannelPropertiesArgs.builder()
            .directLineEmbedCode(directLineEmbedCode?.applyValue({ args0 -> args0 }))
            .extensionKey1(extensionKey1?.applyValue({ args0 -> args0 }))
            .extensionKey2(extensionKey2?.applyValue({ args0 -> args0 }))
            .sites(
                sites?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [DirectLineChannelPropertiesArgs].
 */
@PulumiTagMarker
public class DirectLineChannelPropertiesArgsBuilder internal constructor() {
    private var directLineEmbedCode: Output<String>? = null

    private var extensionKey1: Output<String>? = null

    private var extensionKey2: Output<String>? = null

    private var sites: Output<List<DirectLineSiteArgs>>? = null

    /**
     * @param value Direct Line embed code of the resource
     */
    @JvmName("gkjrcibhgsswbpbv")
    public suspend fun directLineEmbedCode(`value`: Output<String>) {
        this.directLineEmbedCode = value
    }

    /**
     * @param value The extensionKey1
     */
    @JvmName("agavfqxhimqykxqw")
    public suspend fun extensionKey1(`value`: Output<String>) {
        this.extensionKey1 = value
    }

    /**
     * @param value The extensionKey2
     */
    @JvmName("igrigshdtgnrttek")
    public suspend fun extensionKey2(`value`: Output<String>) {
        this.extensionKey2 = value
    }

    /**
     * @param value The list of Direct Line sites
     */
    @JvmName("nutepyppkmfeodne")
    public suspend fun sites(`value`: Output<List<DirectLineSiteArgs>>) {
        this.sites = value
    }

    @JvmName("ykkoicwjcfnuspll")
    public suspend fun sites(vararg values: Output<DirectLineSiteArgs>) {
        this.sites = Output.all(values.asList())
    }

    /**
     * @param values The list of Direct Line sites
     */
    @JvmName("nywqloibhgyeywfh")
    public suspend fun sites(values: List<Output<DirectLineSiteArgs>>) {
        this.sites = Output.all(values)
    }

    /**
     * @param value Direct Line embed code of the resource
     */
    @JvmName("fbjnukrdrlgltgnk")
    public suspend fun directLineEmbedCode(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.directLineEmbedCode = mapped
    }

    /**
     * @param value The extensionKey1
     */
    @JvmName("umstppdvkebuitjp")
    public suspend fun extensionKey1(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.extensionKey1 = mapped
    }

    /**
     * @param value The extensionKey2
     */
    @JvmName("hautnygkujvdrqdh")
    public suspend fun extensionKey2(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.extensionKey2 = mapped
    }

    /**
     * @param value The list of Direct Line sites
     */
    @JvmName("hjkcabbygtibdngt")
    public suspend fun sites(`value`: List<DirectLineSiteArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sites = mapped
    }

    /**
     * @param argument The list of Direct Line sites
     */
    @JvmName("edvqeospugcacqwb")
    public suspend fun sites(argument: List<suspend DirectLineSiteArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            DirectLineSiteArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.sites = mapped
    }

    /**
     * @param argument The list of Direct Line sites
     */
    @JvmName("vtpuhiqwseofxnhv")
    public suspend fun sites(vararg argument: suspend DirectLineSiteArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            DirectLineSiteArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.sites = mapped
    }

    /**
     * @param argument The list of Direct Line sites
     */
    @JvmName("qdyooxfbqabkvwky")
    public suspend fun sites(argument: suspend DirectLineSiteArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(DirectLineSiteArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.sites = mapped
    }

    /**
     * @param values The list of Direct Line sites
     */
    @JvmName("nqrfsqdgnuqmcvmx")
    public suspend fun sites(vararg values: DirectLineSiteArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sites = mapped
    }

    internal fun build(): DirectLineChannelPropertiesArgs = DirectLineChannelPropertiesArgs(
        directLineEmbedCode = directLineEmbedCode,
        extensionKey1 = extensionKey1,
        extensionKey2 = extensionKey2,
        sites = sites,
    )
}
